Najnovšie Články: motoride.sk
Description: Stránka venovaná všetkým priaznivcom motoriek...
Keywords: motorky, obrázky motoriek, motoride, chat, kalendár podujatí, články, testy, videá, motorcycle pictures, bikes, novinky, diskusia, ukradnuté motorky

ISSN 1336-6491 | Online: 1146 | Redakcia

motoride.sk :: Články | Videá | Tipy | Foto | Klub | Inzercia | Firmy | Fórum | Kalendár | Jawa okolo sveta

login: heslo:
Neodhlasovať

## Anketa: Zapojíš sa do kampane Pozri dvakrát, zachrániš život!?
Spolu odpovedi: 5474
áno, určite ju podporím: 53% (2925)
nie, nezaujalo ma to: 47% (2549)
## Pre vás: Povinné zmluvné poistenie - vyber si najlepšiu cenu! | # Najnovšie Články # Mikulášska jazda Bratislava 2014 Pár fotiek z tohtoročnej Mikulášskej jazdy v Bratislave. # MV Agusta Brutale 800 Dragster RR 2015 - Nielen najkrajšia brutka? MV-čka nás už pred výstavou v Miláne začala pomaly navnaďovať na ich najnovší prírastok medzi radu Brutale. Najprv kúsok vypletaného kolesa, potom video s viac pohľadmi a neskôr celú galerku fotiek. No a nakoniec výstava EICMA. # Mikulášska jazda Košice 2014 Na Mikuláša vskutku priaznivé počasie, prilákalo na dnešné cesty rekordný počet bikerov. Previezli sme sa, rozdali sladkosti deťom na Hlavnej a navštívili aj nemocnicu, kde Mikuláš potešil deti na Onkológii. Nechýbala darovačka krvi a ani after-party. # Výstava BRNO NA DVOU KOLECH 2014 - História Grand Prix Brno Technické múzeum v Brne otvorilo od 4. 11. dlhodobú výstavu o histórii cestných pretekov v Brne. Vďaka Jaroslavovi Brzobohatému vám môžeme priniesť niekoľko fotiek z tejto zaujímavej výstavy, ktoré vás možno nalákajú na návštevu. # Na Mikulášsku kvapku krvi pozývajú harlejáci aj novinári Už tento piatok sa uskutoční jubilejná piata Kvapka krvi, ktorú od roku 2012 organizujú prešovskí harlejáci. Každý odber mal pod ich taktovkou väčší záber a tentoraz sa k nim pripoja aj prešovskí novinári. Odber organizujú v spolupráci s Národnou transfúznou stanicou z Prešova. # Veteránske galérie na Morave 3 - Múzeum motorizmu Znojmo Ako som naznačil v letnom putovaní po južnej Morave absolvoval som prehliadky viacerých múzeí s veteránmi. # Malé chladné dobrodružstvo Počasie dnes spoza okna vyzeralo ukážkovo, slnečno, bez jediného mráčika... a že riadne fúkalo, tak to mi hralo do karát. Chcel som len otestovať windstopper kuklu Klim a pozbíjaný tuning kokpitu, no nakoniec z toho bolo celkom pekné ľadové osvieženie. # Potemkinova dedina Skoro by som na tento šibnutý príbeh z histórie zabudol, keby nebolo môjho jediného verného spolupútnika Miloša. V 18. storočí žil v Rusku celkom úspešný chlap. Ešte úspešnejší sa stal po tom, ako sa cárovnej Kataríne II dostal pod sukňu. Volal sa Potemkin a najviac ho preslávil príbeh o ľsti. Pravdepodobne sa to nikdy nestalo. # Honda odhalila novú malorážku CB125F pre rok 2015 Honda dnes odhalila novú 125-ku v rodine CB. Podobne ako jej súrodenci nesie po novom označenie CB125F a prebrala čosi aj z ich dizajnu. # DOPLNENÉ: Števo Svitko - rozhovor pred Dakarom 2015 + ladenie podvozku Prípravy pred Dakarom sú v plnom prúde, motorka je prestriekaná, tlmiče naladené a nový mechanik pripravený. A ako som tak pozeral na Števa pri jeho paľbe, tak sa zdá, že on tiež. DOPLNENÉ: Video z nastavovania podvozku. # PionierCross Budimír 2014 a záver Celoslovenského seriálu v Pioniercrosse 2014 V Budimíri sa uplynulú nedeľu stretli pionieristi, nielen na poslednom preteku sezóny, ale aj na poslednom preteku novovzniknutého Celoslovenského seriálu v Pioniercrosse. Bojovalo sa teda o posledné body do šampionátu. # Beta Urban 200 Special - Pekná, pracovitá, nenáročná... To je jaká preparáda? Toto mňa baví, jak sa patrí, aš na to zabíháňí a asi aj tá maximálka bude slabá, ale zas čekám nula celá nula spotrebu. V mjesce zatát jedno z naj, ovládaňí úplňe na vysokej úrovňi, brzdy keré nebrzdzili úplňe že ňic, tak fčil brzďá aj na stopí, ale treba stlačit rádňe páčku. # Najnovšie: ## Mikulášska jazda Bratislava 2014 tomgarfield - Dnes Pár fotiek z tohtoročnej Mikulášskej jazdy v Bratislave. ## Enduro Crash Testy :-) Tomáš Hajduch - Awia - Dnes Pri jazde v teréne sa vždy pritrafia - kolekcia pádov. Motorky:... ## MV Agusta Stradale 800 2015 datadive - Dnes MV Agusta Stradale 800 2015 ## Mikulášska moto jazda 2014 - Košice pastrana16 - Dnes 6.12.2014 moto mikulášska jazda v Košiciach ## MV Agusta Brutale 800 Dragster RR 2015 -... Milan Mikulík - mikulec - Včera MV-čka nás už pred výstavou v Miláne začala pomaly navnaďovať... ## Balkánska päťka 77speedy - Včera Po minuloročnej dovči na motorke v krásnom severnom Taliansku... ## Muž na Jawe - Francúz o Československých... Tomáš Hajduch - Awia - Včera Príbeh jedného francúzskeho Jawáka a jeho cesty do Týnca n. Sázavou... ## Burt Munro Challenge 2013 Retro - 07.12.2014 Ďalší pretek na Novom Zélande - Burt Munro Challenge Wyndham.... ## Mikulášska jazda Košice 2014 Tomáš Hajduch - Awia - 06.12.2014 Na Mikuláša vskutku priaznivé počasie, prilákalo na dnešné cesty... ## Minigaráž pre motorku smetom - 06.12.2014 Minigaráž pre motorku ## Julien Dupont s trialkou na horskej dráhe... Redakcia Motoride.sk - 05.12.2014 Julien Dupont a jeho jazda na horskej dráhe Montaña Rusa... ## Tričko a DVD Motoride XL Enduro Rally 2014... Tomáš Hajduch - Awia - 05.12.2014 Tak ako sme avizovali pripravili sme pamätné tričko z tohtoročnej... ## Hellas Rally Raid 2014 Tomáš Hajduch - Awia - 05.12.2014 Repotráž z gréckej Rally - Hellas Rally Raid 2014 ## Maxxis FIM majstrovstvá sveta v superendure... Redakcia Motoride.sk - 05.12.2014 V sobotu 6.12.2014 sa v poľskom meste Gdansk uskutočnia Maxxis... ## Erg Chebbi - dunové pole, Maroko Tomáš Hajduch - Awia - 05.12.2014 Erg Chebbi (arabsky: عرق ال... ## One month to Dakar 2015 - fans! Landal - 04.12.2014 Čas sa pomaličky naplňuje, už len mesiac "to go!" ## KTM pripravuje facelift pre radu malých vojdovov Feri Zubal - zeON - 04.12.2014 KTM Duke 125, 200 a 390 dostanú zopár malých úprav. Vstupné modely... ## Nástrahy číhajú na každom kroku - RIDE to... Tomáš Hajduch - Awia - 04.12.2014 Bezpečnostná kampaň z Austrálie. Táto bezpečnostná reklama upozorňuje... ## Peshku camp, Hudënisht, Albánsko headqo - 03.12.2014 Kemp nachádzajúci sa pri Ohridskom Jazere. Súčasťou kempu je... ## Výstava BRNO NA DVOU KOLECH 2014 - História... Retro - 03.12.2014 Technické múzeum v Brne otvorilo od 4. 11. dlhodobú výstavu o... ## Na Mikulášsku kvapku krvi pozývajú harlejáci... Redakcia Motoride.sk - 02.12.2014 Už tento piatok sa uskutoční jubilejná piata Kvapka krvi, ktorú... ## Veteránske galérie na Morave 3 - Múzeum motorizmu... gilbert - 02.12.2014 Ako som naznačil v letnom putovaní po južnej Morave absolvoval... ## Junior Moto Academy je lákavá aj pre dievčatá Risso46 - 02.12.2014 Už tretí rok existencie má za sebou detská motocyklový akadémia,... ## Tiszavirág Camping, Maďarsko headqo - 01.12.2014 Kemping pri rieke Tisza. Moznost ubytovania aj v izbach - prerobene... ## Nakúpte najvýhodnejšie moto darčeky! Redakcia Motoride.sk - 01.12.2014 Využite špeciálne predvianočné zľavy až do -40 % v e-shope Honda,... ## Novinky 2015: Ducati Scrambler - V jednoduchosti... Feri Zubal - zeON - 01.12.2014 Jednoducho vyzerajúci stroj s názvom Ducati Scrambler bol bezpochyby... ## Vianočné tipy 2014 - darčeky pre bikera aj... Redakcia Motoride.sk - 01.12.2014 Tak ako každý rok aj v tomto roku prinášame pred vianocami niekoľko... ## Wanganui Cemetery Circuit 2013 - F2 Supersport... Retro - 30.11.2014 Zatiaľ čo sa Európe nič nedeje, na Novom Zélande sa pretekať... ## Malé chladné dobrodružstvo Feri Zubal - zeON - 29.11.2014 Počasie dnes spoza okna vyzeralo ukážkovo, slnečno, bez jediného... ## Bilancovanie sezóny 2014 na SLOVAKIA RINGU Redakcia Motoride.sk - 29.11.2014 Jediný slovenský permanentný automotodróm SLOVAKIA RING pri Orechovej... ## Ukážka: ABS na motorke - Áno či nie? Redakcia Motoride.sk - 28.11.2014 Ukážka brzdenia na mokrej vozovke so zapnutým a vypnutým systémom... ## Vergina - kráľovské hrobky, Grécko Landal - 27.11.2014 Územie dnešného Grécka je plné pozoruhodných pamiatok, ale medzi...
## Motocykle Testy Novinky Bleskovky ## Tričko a DVD Motoride XL Enduro Rally 2014... Tomáš Hajduch - Awia - 05.12.2014 Tak ako sme avizovali pripravili sme pamätné tričko z tohtoročnej... ## KTM pripravuje facelift pre radu malých vojdovov Feri Zubal - zeON - 04.12.2014 KTM Duke 125, 200 a 390 dostanú zopár malých úprav. Vstupné modely... ## Nakúpte najvýhodnejšie moto darčeky! Redakcia Motoride.sk - 01.12.2014 Využite špeciálne predvianočné zľavy až do -40 % v e-shope Honda,... ## Špionážne fotografie: KTM 1290 SMT - ďalší... Feri Zubal - zeON - 26.11.2014 Bolo len otázkou času kedy v KTM postavia ďalší model s motorom... ## Honda dosiahla globálny míľnik - 300 miliónov... Redakcia Motoride.sk - 25.11.2014 Utorok 25. novembra 2014 – Spoločnosť Honda Motor Co., Ltd.,... Ďalšie články » | ## Šport Cesta Off-road ## Maxxis FIM majstrovstvá sveta v superendure... Redakcia Motoride.sk - 05.12.2014 V sobotu 6.12.2014 sa v poľskom meste Gdansk uskutočnia Maxxis... ## Motoshop Žubor ples 2014 Milan Mikulík - mikulec - 25.11.2014 Srdečne Vás pozývame na 3.Motoshop Žubor ples, ktorý sa uskutoční... ## V Jereze dekorovali majstrov sveta 2014 a... Redakcia Motoride.sk - 24.11.2014 V dňoch 22. – 23.11.2014 sa v španielskom meste Jerez de la Frontera... ## PionierCross Budimír 2014 a záver Celoslovenského... Tomáš Hajduch - Awia - 19.11.2014 V Budimíri sa uplynulú nedeľu stretli pionieristi, nielen na... ## ISDE 2015 SLOVENSKO, Košice – úspešná prezentácia... Redakcia Motoride.sk - 11.11.2014 V týchto dňoch sa vrátila výprava ISDE 2015, reprezentovaná Slovenskou... Ďalšie články »
## Mototuristika Cestopisy Výlety a akcie Tipy ## Hotel PTTK, Pszczyna, Poľsko headqo - Včera Hotel v meste Pszczyna. Parkovanie uzamknutom dvore za hotelom... ## Zámok Pszczyna, Poľsko headqo - 07.12.2014 Veľmi pekný neobarokovy zámok spolu s veľkou záhradou so skanzenom... ## Erg Chebbi - dunové pole, Maroko Tomáš Hajduch - Awia - 05.12.2014 Erg Chebbi (arabsky: عرق ال... ## Peshku camp, Hudënisht, Albánsko headqo - 03.12.2014 Kemp nachádzajúci sa pri Ohridskom Jazere. Súčasťou kempu je... ## Technické múzeum, Brno, Česko Tomáš Hajduch - Awia - 03.12.2014 Technické muzeum v Brně obsahuje rôzne expozície hlavne z územia... Ďalšie body a trasy » | ## Ostatné Vaše Stroje Technika História ## Kde sa zrodil "zobák" - dizajnový prvok dnešných... Tomáš Hajduch - Awia - 22.10.2014 Napriek tomu, že si mnohí myslia že "Zobák" je vynález BMW pravda... ## Bankovský kopec 2014 - súťaž v jazde pravidelnosti... Tomáš Hajduch - Awia - 29.09.2014 Po zmene termínu a odložení akcie o jeden týždeň, dnes počasie... ## História Pionier: Laminátový prorotyp Pioniera... gilbert - 29.07.2014 Pionier bol druhý považský fenomén. Jeho genézia je stále opradená... ## FIM v roku 2014 oslavuje 110. výročie založenia Redakcia Motoride.sk - 24.04.2014 Medzinárodná motocyklová federácia FIM predstavila logo k 110.... ## Minimotocykle pre deti na báze Pionier 550 gilbert - 23.04.2014 Ako som spomínal v období socializmu a uniformity sa okrem spomínaných... Ďalšie články »
## Najbližšie akcie 13.12.2014 [Pionier Cup] ### Pioniercross KOPERNICA 2014 Kopernica POZOR ZMENA DÁTUMU PRETEKOV!!! Z technických príčin preteky prekladáme... 15.12.2014 [Enduro] ### FIM majstrovstvá sveta SuperEnduro 2015 Lodz/Atlas Arena, Poľsko FIM majstrovstvá sveta SuperEnduro 2014 21.12.2014 - 25.12.2014 [Motoakcie, Stretnutia] ### Motorkárska Lyžovačka 2015 Mölltaler Gletscher 21.01. – 25.01. CUSTOM CHOPPERS SK, cestovná agentúra pre Vás pripravila Motorkársku... 15.05.2015 - 17.05.2015 [Motoakcie, Stretnutia] ### MOTO HADINKA 2015 Klokočov u Vítkova Beskyd's Raiders Vás zve na 4. ročník srazu moto hadinka 2015... 05.06.2015 - 07.06.2015 [Motoakcie, Stretnutia] ### NÁRODNÝ MOTOCYKLOVÝ ZRAZ Piešťany | ## Vaša Inzercia 09.12.2014 (17:35) ### Pánska kombinéza na motorku RSA Compact - 2 dielna Bunda: Vrchný materiál CORDURA ®. Špičkový technický materiál s extrémnou pevnosťou a odolnosťou proti... 09.12.2014 (17:34) ### Puzdro na navigácie Oxford - pre športové motocykl - univerzálne puzdro pre uchytenie na riadidlá športových a cestovných motocyklov - dvojvrstvová konštrukcia... 09.12.2014 (17:27) ### Prídavné svetlá MP2 - White - Prídavné svetlá halogénové - materiál : hliník - žiarovky v balení - sada 2 svetiel - Schválenie:... 09.12.2014 (17:27) ### GoPro - Nálepky 3M zahnuté Nálepky zahnuté pre kamery GOPRO kvalitný 3M materiál lepiacej plochy jednoduchá aplikácia na rovné... 09.12.2014 (17:27) ### Nášivka Route66 Veľmi kvalitne vyšitá motocyklová nášivka o rozmere 50mm x 50mm.
Ďalšie akcie » | Ďalšie inzeráty »
# Diskusné fórum
| Predmet: | Autor: | Posledná zmena:
--- | --- | --- | ---
| Výlet, Stretko Stretnutia TA Rh+ 2014 [Stránky: 1 ... 3, 4, 5] | superflanker | 09.12.14 (17:33) keduska
| HONDA CB500F, CBR500,CB500X chyba Vam vykon? | salat | 09.12.14 (17:26) janoval
| Okruhovka 600ccm [Stránky: 1, 2, 3] | Caba | 09.12.14 (17:04) kralik
| Posed Ladvinky na Motorke | Stano600 | 09.12.14 (16:46) Dermo33
| MV Agusta Brutale 800 Dragster RR 2015 - Nielen najkrajšia... | Sano | 09.12.14 (16:34) WarLord
| Moja dalsia motorka :) | Miki23 | 09.12.14 (16:31) Cukero
| Výlet, Stretko Mikulášska jazda 2014 - Bratislava | trojko | 09.12.14 (14:50) Pulinsky
| Moto Girl Trip: 07 - Čo všetko sme ochotní obetovať... | NIKDENIKTO | 09.12.14 (13:01) jogcar
| Števo Svitko - rozhovor z testovania pred Dakarom 2015 | Awia | 09.12.14 (11:41) jogcar
| Trasa: Erg Chebbi - dunové pole, Maroko | matus | 09.12.14 (11:13) Menton
| ## Najnovšie videá: ## Enduro Crash Testy :-) 07:51 ## MV Agusta Stradale 800 2015 01:10 ## Mikulášska moto jazda 2014 - Košice 06:01 ▼ Zobraz viac ▼ ## Muž na Jawe - Francúz o Československých... 50:20 ## Moto - Mikulášska jazda 2014 - Bratislava 02:30 ## Burt Munro Challenge 2013 04:01 ## Neprehliadnite: 22.10.2014 - datadive [Testy a predstavenia - Vyskúšali sme] ### Honda CTX 700 DCT ABS 2014 - Kam to bude, pane? Viac » 06.11.2014 - mikulec [Testy a predstavenia - Vyskúšali sme] ### Beta RR 300 a 350 EFI na motokrosovom preteku Viac » 10.11.2014 - zeON [Testy a predstavenia - Test] ### Prvý test: Honda VFR800X Crossrunner 2015 - Pohodlie, šport a tak trochu adventure Viac » ## Nový člen: Login: aapa Motorka: SCV 100 Lead Mesto: Šaľa ## Galéria: Dnes - gilbert Ďalšie fotografie » ## Tričko Motoride.sk Tričko a šiltovka pre všetkých priaznivcov servera MotoRide... Zasielanie tovaru obnovené! Šiltovka motoride.sk. ## Počasie: In-počasie ## Vtip Pridal: demmoo Včera som pozeral porno. V tom prišla mama. Musel som si to trikrát pretočiť, lebo som nechcel veriť, že to je ona. Ďalšie vtipy »